C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LDM_SET_PHIX     **
C**************************
C
C
CD-Doc:
C PHIX             SUBROUTINE LDM_SET_PHIX (IPACK, VALUE, IERR, ERRSTR)
CD-end
      SUBROUTINE LDM_SET_PHIX (IPACK, VALUE, IERR, ERRSTR)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Set value of pack dependent real parameter PHIX
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      INTEGER IPACK
      REAL    VALUE
      INTEGER IERR
      CHARACTER*(*) ERRSTR

C  IPACK     (R)   Pack number, 0=all packs
C  VALUE     (R)   Value for PhiX in degrees (any)
C  IERR      (W)   Error flag =0 OK
C                             =-1 Invalid pack number
C  ERRSTR    (W)   Error description string if error found
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      INCLUDE 'ldm_lrl.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
      IERR = 0
      ERRSTR = ' '
      CALL LDM_CHK_SPK (IPACK, IERR, ERRSTR)
      IF (IERR.NE.0) RETURN
      CALL LDM_SETF_PK (IPACK, PHIX, IS_PHIX, CH_PHIX, ND_PHIX, 
     +                  VALUE, LDM_MAXPK)
      CALL LDM_CLR_GEN (IPACK, -1, 1)
      RETURN
      END
